/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the pig4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

import request from '@/router/axios'

export function fetchList(query) {
  return request({
    url: '/da/tunnel/page',
    method: 'get',
    params: query
  })
}

export function addObj(obj) {
  return request({
    url: '/da/tunnel',
    method: 'post',
    data: obj
  })
}

export function getObj(id) {
  return request({
    url: '/da/tunnel/' + id,
    method: 'get'
  })
}

export function delObj(id) {
  return request({
    url: '/da/tunnel/' + id,
    method: 'delete'
  })
}

export function putObj(obj) {
  return request({
    url: '/da/tunnel',
    method: 'put',
    data: obj
  })

}

export function tunnelById(stationCode,tunnelId) {
  return request({
    url: '/da/tunnel/tunnelId/'+stationCode+'/'+tunnelId,
    method: 'get'

  })
}


export function tunnelStation(stationCode) {
  return request({
    url: '/da/tunnel/station/'+stationCode,
    method: 'get'

  })
}

export function tunnelTyps() {
  return request({
    url: '/da/tunnel/tunnelType',
    method: 'get'

  })
}


export function tunnelState(obj) {
  return request({
    url: '/da/tunnel/link/status',
    method: 'post',
    data: obj
  })
}

export function tunnelFindInstation(stations) {
  return request({
    url: '/da/tunnel/findInStation',
    method: 'post',
    data: stations
  })
}

export function tunnelConnect(tunnel) {
  return request({
    url: '/da/tunnel/connect',
    method: 'post',
    data: tunnel
  })
}

export function tunnelDisconnect(tunnel) {
  return request({
    url: '/da/tunnel/disConnect',
    method: 'post',
    data: tunnel
  })
}

export function tunnelReconnect(tunnel) {
  return request({
    url: '/da/tunnel/reConnect',
    method: 'post',
    data: tunnel
  })
}

export function getThreadCount() {
  return request({
    url: '/da/tunnel/getThreadCount',
    method: 'get'

  })
}
